Packet

Struct Packet 

pub struct Packet { /* private fields */ }
Represents a wintun packet

Implementations

Source

impl Packet

pub fn bytes_mut(&mut self) -> &mut [u8]

Returns the bytes this packet holds as &mut. The lifetime of the bytes is tied to the lifetime of this packet.

pub fn bytes(&self) -> &[u8]

Returns an immutable reference to the bytes this packet holds. The lifetime of the bytes is tied to the lifetime of this packet.